.. _orion.evaluation:

orion.evaluation
================

.. currentmodule:: orion.evaluation

Contextual Metrics
~~~~~~~~~~~~~~~~~~

.. autosummary::
   :toctree: api/

   contextual_accuracy
   contextual_precision
   contextual_recall
   contextual_f1_score
   contextual_confusion_matrix

Point Metrics
~~~~~~~~~~~~~

.. autosummary::
   :toctree: api/

   point_accuracy
   point_precision
   point_recall
   point_f1_score
   point_confusion_matrix
